@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 10657 2017-12-18 09:18:37Z David $
+# $Id: Mailer.py 10775 2018-02-07 09:28:57Z David $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,14 +13,15 @@
 #
 # $Author: David $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10657 $
+# $Revision: 10775 $
 
 import os
 import random
 import mimetypes
 import time
-from datetime import datetime
+import threading
 
+from datetime import datetime
 from smtplib import SMTPRecipientsRefused
 
 from django.core.mail import EmailMessage
@@ -46,7 +47,7 @@ from Iuno.cloud.mail import EmailBackend
 from Iuno.cloud.mail import SendMessageException, RetryAndSendException
 
 from Theophrastus.models import ContactMailingStatus, Newsletter
-from Theophrastus.newsletter_extension.models import Header, Footer
+from Theophrastus.newsletter_extension.models import Header, Footer, ErrorMessage
 from Theophrastus.cloud.service import CloudService
 from Theophrastus.Utility import getComment, trackLinks
 
@@ -143,6 +144,8 @@ class CloudMailer(Mailer):
             self.logger.info(
                 '[%d]__init__: Open fake SMTP mode.' % newsletter.id)
 
+        self.smtpLock = threading.Lock()
+
     def _getFileContent(self, path):
         """
         Get file content from path.
@@ -359,11 +362,14 @@ class CloudMailer(Mailer):
                 
             else:
                 message = self.build_message(contact)
-                self.smtp.sendmail(
-                    smart_str(self.newsletter.header_sender),
-                    contact.email,
-                    message.as_string()
-                )
+                
+                with self.smtpLock:    
+                    self.smtp.sendmail(
+                        smart_str(self.newsletter.header_sender),
+                        contact.email,
+                        message.as_string()
+                    )
+
                 result = True
                 resultMessage = 'Send mail success.'
 
