@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 10694 2017-12-29 09:22:09Z David $
+# $Id: admin.py 10749 2018-01-29 16:27:24Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-12-29 17:22:09 +0800 (Fri, 29 Dec 2017) $
-# $Revision: 10694 $
+# $Date: 2018-01-30 00:27:24 +0800 (Tue, 30 Jan 2018) $
+# $Revision: 10749 $
 
 from django.contrib import admin
 from django.contrib.admin.views.main import ChangeList
@@ -28,6 +28,7 @@ from Theophrastus.integration.forms import NewsletterIntegrationForm
 from Theophrastus.integration.models import (
     App, Group, GroupMappingTable
 )
+
 integrationSrv = IntegrationService.getInstance()
 
 class AppChangeList(ChangeList):
@@ -211,7 +212,12 @@ class GroupAdmin(admin.ModelAdmin):
     getLastUpdatedTime.allow_tags = True
 
     def displayHistory(self, obj):
-        return '<a href="%d">-</a>' % (obj.id)
+        return '<a href="%s">%s</a>' % (
+            reverse(
+                'Theophrastus.admin.integration.views.getGroupHistory', 
+                kwargs={'groupId': obj.id}
+            ), _('View historic')
+        )
     displayHistory.short_description = _('History')
     displayHistory.allow_tags = True
 
