@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10749 2018-01-29 16:27:24Z David $
+# $Id: __init__.py 10762 2018-02-02 07:47:39Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-01-30 00:27:24 +0800 (Tue, 30 Jan 2018) $
-# $Revision: 10749 $
+# $Date: 2018-02-02 15:47:39 +0800 (Fri, 02 Feb 2018) $
+# $Revision: 10762 $
 
 from django.conf.urls import url, patterns
 
@@ -39,7 +39,7 @@ urlpatterns = patterns('',
         views.getGroups,
         name='Theophrastus.admin.integration.views.getGroups'),
 
-    url(r'^admin/integration/tracking/historic/(?P<groupId>\d+)/$',
+    url(r'^tracking/historic/(?P<groupId>\d+)/$',
         views.getGroupHistory,
         name='Theophrastus.admin.integration.views.getGroupHistory'),
 )
