@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10749 2018-01-29 16:27:24Z David $
+# $Id: views.py 10769 2018-02-06 08:59:35Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-01-30 00:27:24 +0800 (Tue, 30 Jan 2018) $
-# $Revision: 10749 $
+# $Date: 2018-02-06 16:59:35 +0800 (Tue, 06 Feb 2018) $
+# $Revision: 10769 $
 
 import base64
 from datetime import datetime
@@ -482,7 +482,10 @@ def getGroupHistory(request, groupId):
 
 
     context = {'title': _('Historic of %s') % group.name,
-               'mailingStatus': mailingStatus}
+               'mailingStatus': mailingStatus,
+               'statisticsLink': group.statisticsUrl,
+               'subscribersLink': group.subscriberUrl,
+              }
     return render_to_response('NewsletterIntegrationHistoric.html',
                               context, context_instance=RequestContext(request))
 
