@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 10744 2018-01-28 15:00:13Z David $
+# $Id: StatisticsHandler.py 10762 2018-02-02 07:47:39Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-01-28 23:00:13 +0800 (Sun, 28 Jan 2018) $
-# $Revision: 10744 $
+# $Date: 2018-02-02 15:47:39 +0800 (Fri, 02 Feb 2018) $
+# $Revision: 10762 $
 
 from datetime import timedelta, datetime
 
@@ -385,45 +385,45 @@ def countStatus(queryset, historyMode='general'):
 #     uniqueClicked = len(set(clickedLinks.values_list(
 #                               'contact', flat=True)))
     if historyMode == 'history':
-        return [{
-            'sentTest': len(sentTestNumber),
-            'deliverie': len(sentNumber),
-            'error': len(errorLogs),
-            'invaild': len(invaildLogs),
-            'open': len(openId),
-            'openOnSite': len(openOnSiteId),
-            'click': len(clickId),
-            'unsubscribe': len(unsubscriptionNumber),
-            'bounce': len(bouncedLogs),
-            'complain': len(complainLogs),
-            'reject': len(rejectedLogs),        
-            
+        return [
+            {
+                'sentTest': len(sentTestNumber),
+                'deliverie': len(sentNumber),
+                'error': len(errorLogs),
+                'invaild': len(invaildLogs),
+                'open': len(openId),
+                'openOnSite': len(openOnSiteId),
+                'click': len(clickId),
+                'unsubscribe': len(unsubscriptionNumber),
+                'bounce': len(bouncedLogs),
+                'complain': len(complainLogs),
+                'reject': len(rejectedLogs),        
             },
             {
-            'openId': openId,
-            'openOnSiteId': openOnSiteId,
-            'clickId': clickId
+                'openId': openId,
+                'openOnSiteId': openOnSiteId,
+                'clickId': clickId
             }            
         ]
     else:
-        return [{
-            'sentTest': len(sentTestNumber),
-            'deliverie': len(sentNumber),
-            'error': len(errorLogs),
-            'invaild': len(invaildLogs),
-            'open': len(openLogs),
-            'openOnSite': len(openOnSiteLogs),
-            'click': len(clickLogs),
-            'unsubscribe': len(unsubscriptionNumber),
-            'bounce': len(bouncedLogs),
-            'complain': len(complainLogs),
-            'reject': len(rejectedLogs),        
-            
+        return [
+            {
+                'sentTest': len(sentTestNumber),
+                'deliverie': len(sentNumber),
+                'error': len(errorLogs),
+                'invaild': len(invaildLogs),
+                'open': len(openLogs),
+                'openOnSite': len(openOnSiteLogs),
+                'click': len(clickLogs),
+                'unsubscribe': len(unsubscriptionNumber),
+                'bounce': len(bouncedLogs),
+                'complain': len(complainLogs),
+                'reject': len(rejectedLogs),        
             },
             {
-            'openId': openId,
-            'openOnSiteId': openOnSiteId,
-            'clickId': clickId
+                'openId': openId,
+                'openOnSiteId': openOnSiteId,
+                'clickId': clickId
             }            
         ]
 
